;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "magit-section" "20260731.2248"
  "Sections for read-only buffers."
  '((emacs    "28.1")
    (compat   "31.0")
    (cond-let "1.1")
    (llama    "1.0")
    (seq      "2.24"))
  :url "https://github.com/magit/magit"
  :commit "67f203853e74e926e2c99f60ed508840714f7ced"
  :revdesc "67f203853e74"
  :keywords '("tools")
  :authors '(("Jonas Bernoulli" . "emacs.magit@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.magit@jonas.bernoulli.dev")))
